==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeries, _super);
    function ScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSeries.$;
        _this.rq = new ScatterFrame();
        _this.rs = new ScatterFrame();
        _this.ro = new ScatterFrame();
        return _this;
    }
    ScatterSeries.prototype.get_c1 = function () {
        return true;
    };
    ScatterSeries.prototype.bv = function () {
        return new ScatterSeriesView(this);
    };
    ScatterSeries.prototype.gl = function () {
        return 0.7;
    };
    ScatterSeries.prototype.pu = function () {
        if (this.pt == 0) {
            return 2;
        }
        return _super.prototype.pu.call(this);
    };
    ScatterSeries.prototype.lo = function (a) {
        _super.prototype.lo.call(this, a);
        this.ud = a;
    };
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
}(ScatterBase));
export { ScatterSeries };
/**
 * @hidden
 */
var ScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesView, _super);
    function ScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.df = null;
        _this.df = a;
        return _this;
    }
    ScatterSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.p0 = Defaults.e;
        }
    };
    ScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.o0 = a;
        this.e.gm = 3;
        this.e.gn = 2;
        this.e.go = 2;
        this.e.e3 = false;
    };
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
}(ScatterBaseView));
export { ScatterSeriesView };

==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeries, _super);
    function ScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSeries.$;
        _this.r3 = new ScatterFrame();
        _this.r5 = new ScatterFrame();
        _this.r1 = new ScatterFrame();
        return _this;
    }
    ScatterSeries.prototype.get_c4 = function () {
        return true;
    };
    ScatterSeries.prototype.bx = function () {
        return new ScatterSeriesView(this);
    };
    ScatterSeries.prototype.gv = function () {
        return 0.7;
    };
    ScatterSeries.prototype.p7 = function () {
        if (this.p6 == 0) {
            return 2;
        }
        return _super.prototype.p7.call(this);
    };
    ScatterSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.u2 = a;
    };
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
}(ScatterBase));
export { ScatterSeries };
/**
 * @hidden
 */
var ScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesView, _super);
    function ScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.df = null;
        _this.df = a;
        return _this;
    }
    ScatterSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.qd = Defaults.e;
        }
    };
    ScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pb = a;
        this.e.gw = 3;
        this.e.gx = 2;
        this.e.gy = 2;
        this.e.e7 = false;
    };
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
}(ScatterBaseView));
export { ScatterSeriesView };
